@@ -6,7 +6,10 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Set;
 
+import org.gcube.datacatalogue.common.enums.Fishery_Type;
+import org.gcube.datacatalogue.common.enums.Product_Type;
 import org.gcube.datacatalogue.common.enums.Status;
+import org.gcube.datacatalogue.common.enums.Stock_Type;
 import org.gcube.datacatalogue.grsf_manage_widget.client.GRSFManageWidgetService;
 import org.gcube.datacatalogue.grsf_manage_widget.client.GRSFManageWidgetServiceAsync;
 import org.gcube.datacatalogue.grsf_manage_widget.client.events.EnableConfirmButtonEvent;
@@ -39,6 +42,7 @@ import com.github.gwtbootstrap.client.ui.constants.ButtonType;
 import com.github.gwtbootstrap.client.ui.event.HiddenEvent;
 import com.github.gwtbootstrap.client.ui.event.HiddenHandler;
 import com.google.gwt.core.client.GWT;
+import com.google.gwt.dom.client.Element;
 import com.google.gwt.dom.client.SelectElement;
 import com.google.gwt.dom.client.Style.Unit;
 import com.google.gwt.event.dom.client.ChangeEvent;
@@ -84,10 +88,13 @@ public class ManageProductWidget extends Composite{
 	TextArea shortNameTextBox;
 
 	@UiField
-	TextBox productGrsfType;
+	ListBox productGrsfTypeListbox;
 
 	@UiField
 	CheckBox traceabilityFlag;
+	
+	@UiField
+	CheckBox sdgFlag;
 
 	@UiField
 	TextArea GRSFNameTexBox;
@@ -189,7 +196,7 @@ public class ManageProductWidget extends Composite{
 
 		// show modal
 		manageProductModal.addStyleName("management-metadata-modal-style");
-		//		manageProductModal.getElement().getStyle().setWidth(60, Unit.PCT);
+		((Element)manageProductModal.getElement().getChildNodes().getItem(1)).addClassName("modal-body-custom");
 		manageProductModal.show();
 
 		manageProductModal.addHiddenHandler(new HiddenHandler() {
@@ -275,12 +282,31 @@ public class ManageProductWidget extends Composite{
 								});
 
 								semanticIdentifierTextBox.setText(bean.getSemanticIdentifier());
-								productGrsfType.setText(bean.getGrsfType());
+								
+								// update product type listbox.. get the available types for the record under management
+								List<String> types = getTypesForRecord(bean.getDomain());
+								productGrsfTypeListbox.addItem(bean.getCurrentGrsfType(), bean.getCurrentGrsfType());
+								
+								for (String type : types) {
+									productGrsfTypeListbox.addItem(type, type);
+								}
+								
+								//select the current
+ 								productGrsfTypeListbox.setSelectedValue(bean.getCurrentGrsfType());
+
+								productGrsfTypeListbox.addChangeHandler(new ChangeHandler() {
+
+									@Override
+									public void onChange(ChangeEvent event) {
+										eventBus.fireEvent(new EnableConfirmButtonEvent());
+									}
+								});
 								currentStatus.setText(bean.getCurrentStatus().toString());
+								
+								// traceability flag
 								traceabilityFlag.setValue(bean.isTraceabilityFlag());
 								traceabilityFlag.setText("Traceability");
-								traceabilityFlag.setTitle("Current value for this flag in the Knowledge Base is " + bean.isTraceabilityFlag());
-
+								traceabilityFlag.setTitle("Current value for this flag is " + bean.isTraceabilityFlag());
 								traceabilityFlag.addClickHandler(new ClickHandler() {
 
 									@Override
@@ -288,7 +314,19 @@ public class ManageProductWidget extends Composite{
 										eventBus.fireEvent(new EnableConfirmButtonEvent());
 									}
 								});
+								
+								// sdg flag
+								sdgFlag.setValue(bean.isSdgFlag());
+								sdgFlag.setText("Sustainable Development Goals");
+								sdgFlag.setTitle("Current value for this flag is " + bean.isSdgFlag());
+								sdgFlag.addClickHandler(new ClickHandler() {
 
+									@Override
+									public void onClick(ClickEvent event) {
+										eventBus.fireEvent(new EnableConfirmButtonEvent());
+									}
+								});
+								
 								// manage sources
 								List<SourceRecord> availableSources = bean.getSources();
 								panelForSourceItems.add(new SourceWidget(availableSources));
@@ -312,7 +350,9 @@ public class ManageProductWidget extends Composite{
 								// check for new status box
 								List<Status> statusToShow = new ArrayList<Status>(STATUS);
 								statusToShow.remove(bean.getCurrentStatus());
-								statusToShow.remove(Status.To_be_Merged); // it cannot be set by a user
+								
+								// remove to be merged, since it cannot be set by a user
+								statusToShow.remove(Status.To_be_Merged); 
 
 								// if the record isn't approved, then remove also archived
 								if(!bean.getCurrentStatus().equals(Status.Approved))
@@ -395,9 +435,19 @@ public class ManageProductWidget extends Composite{
 		bean.setShortNameUpdated(shortNameTextBox.getText());
 
 		if(!bean.getShortName().equals(bean.getShortNameUpdated())){
-			report += "\n- The GRSF Short Name has been changed to '" + bean.getShortNameUpdated() + "', from '" + bean.getShortName() + "'";
+			report += "\n- The GRSF Short Name has been changed to '" + bean.getShortNameUpdated() + "' from '" + bean.getShortName() + "';";
 			hashtags.add(HashTagsOnUpdate.SHORTNAME_UPDATED.getString());
 		}
+		
+		// status
+		bean.setNewGrsfType(productGrsfTypeListbox.getSelectedItemText());
+		if(bean.getNewGrsfType().equalsIgnoreCase(bean.getCurrentGrsfType())){
+			report += "\n- The GRSF Type is unchanged;";
+		}
+		else{
+			report += "\n- The GRSF Type has been changed to '" + bean.getNewGrsfType() + "' from '" +  bean.getCurrentGrsfType() + "';";
+			hashtags.add(HashTagsOnUpdate.GRSF_TYPE_CHANGED.getString());
+		}
 
 		// evaluate the connections and the actions on them
 		bean.setConnections(connectWidget.getConnectList());
@@ -464,6 +514,20 @@ public class ManageProductWidget extends Composite{
 		// update the traceability flag
 		bean.setTraceabilityFlag(traceabilityNewValue);
 		
+		// sdg flag
+		Boolean sdgNewValue = sdgFlag.getValue();
+		boolean currentSdgFlag = bean.isSdgFlag();
+		if(!sdgNewValue.equals(currentSdgFlag)){
+			report += "\n- SDG flag has been changed to: '" + sdgNewValue + "';";
+			if(sdgNewValue)
+				hashtags.add(HashTagsOnUpdate.SDG_FLAG_SET.getString());
+			else
+				hashtags.add(HashTagsOnUpdate.SDG_FLAG_UNSET.getString());
+		}
+		
+		// update the traceability flag
+		bean.setSdgFlag(sdgNewValue);
+		
 		// force the new status in the listbox
 		if(bean.isMergesInvolved()){
 			bean.setNewStatus(Status.To_be_Merged);
@@ -533,5 +597,17 @@ public class ManageProductWidget extends Composite{
 		infoBlock.setType(type);
 		infoBlock.setVisible(true);
 	}
+	
+	/**
+	 * Retrieve the list of types for stocks and fisheries, given the domain
+	 * @param domain
+	 * @return a list of types
+	 */
+	private List<String> getTypesForRecord(
+			String domain) {
+		if(domain == null)
+			throw new RuntimeException("GRSF Domain is missing!");
+		return domain.equalsIgnoreCase(Product_Type.FISHERY.getOrigName()) ? Fishery_Type.getTypesAsListString() : Stock_Type.getTypesAsListString();
+	}
 
 }
